@@ -93,19 +93,31 @@ sub duplicates {
 }
 
 #-----------------------------------------------------------------------------
+#
+#sub value_parse {
+#    my ( $self, $line ) = @_;
+#    
+#    my @items = split /;/, $line;
+#    
+#    my %h;    
+#    foreach my $i (@items) {
+#        $i =~ /(.*)=(.*)/g;
+#        $h{$1} = $2;
+#    }
+#    return (\%h);
+#}
+#=head2 value_parse 
+#
+#    Title    : value_parse
+#    Usage    : $obj->value_parse(\@values)
+#    Function : Take arrayref of pragma values seperated by ';'
+#               and returns a hashref of key values pair
+#               example key=value;value
+#    Returns  : Hashref of pragma key-values pairs.
+#    
+#=cut
+
 
-sub value_parse {
-    my ( $self, $line ) = @_;
-    
-    my @items = split /;/, $line;
-    
-    my %h;    
-    foreach my $i (@items) {
-        $i =~ /(.*)=(.*)/g;
-        $h{$1} = $2;
-    }
-    return (\%h);
-}
 
 #-----------------------------------------------------------------------------
 
